@@ -52,7 +52,6 @@
 #include "gpm-backlight.h"
 #include "gpm-kbd-backlight.h"
 #include "gpm-stock-icons.h"
-#include "gpm-tray-icon.h"
 #include "gpm-engine.h"
 #include "gpm-upower.h"
 #include "gpm-disks.h"
@@ -96,7 +95,6 @@ struct GpmManagerPrivate
 	GpmIdle			*idle;
 	GpmControl		*control;
 	GpmScreensaver		*screensaver;
-	GpmTrayIcon		*tray_icon;
 	GpmEngine		*engine;
 	GpmBacklight		*backlight;
 	GpmKbdBacklight		*kbd_backlight;
@@ -109,7 +107,6 @@ struct GpmManagerPrivate
 	UpClient		*client;
 	gboolean		 on_battery;
 	gboolean		 just_resumed;
-	GtkStatusIcon		*status_icon;
 	NotifyNotification	*notification_general;
 	NotifyNotification	*notification_warning_low;
 	NotifyNotification	*notification_discharging;
@@ -692,6 +689,60 @@ gpm_manager_action_hibernate (GpmManager *manager, const gchar *reason)
 	return TRUE;
 }
 
+/**
+ * gpm_manager_logout:
+ **/
+static gboolean
+gpm_manager_logout (GpmManager *manager)
+{
+	gboolean ret = FALSE;
+	GVariant *retval = NULL;
+	GError *error = NULL;
+	GDBusProxy *proxy = NULL;
+	GDBusConnection *connection;
+
+	/* connect to gnome-session */
+	connection = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &error);
+	if (connection == NULL) {
+		g_warning ("Failed to connect to the session: %s", error->message);
+		g_error_free (error);
+		goto out;
+	}
+	proxy = g_dbus_proxy_new_sync (connection,
+			G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES |
+			G_DBUS_PROXY_FLAGS_DO_NOT_CONNECT_SIGNALS,
+			NULL,
+			"org.gnome.SessionManager",
+			"/org/gnome/SessionManager",
+			"org.gnome.SessionManager",
+			NULL, &error);
+	if (proxy == NULL) {
+		g_warning ("Failed to shutdown session: %s", error->message);
+		g_error_free (error);
+		goto out;
+	}
+
+	/* ask to shut it down */
+	retval = g_dbus_proxy_call_sync (proxy,
+					 "Shutdown",
+					 NULL, G_DBUS_CALL_FLAGS_NONE,
+					 -1, NULL, &error);
+	if (retval == NULL) {
+		g_debug ("Failed to shutdown session: %s", error->message);
+		g_error_free (error);
+		goto out;
+	}
+
+	/* success */
+	ret = TRUE;
+out:
+	if (retval != NULL)
+		g_variant_unref (retval);
+	if (proxy != NULL)
+		g_object_unref (proxy);
+	return ret;
+}
+
 /**
  * gpm_manager_perform_policy:
  * @manager: This class instance
@@ -726,6 +777,9 @@ gpm_manager_perform_policy (GpmManager  *manager, const gchar *policy_key, const
 		g_debug ("shutting down, reason: %s", reason);
 		gpm_control_shutdown (manager->priv->control, NULL);
 
+	} else if (policy == GPM_ACTION_POLICY_INTERACTIVE) {
+		g_debug ("logout, reason: %s", reason);
+		gpm_manager_logout (manager);
 	} else {
 		g_warning ("unknown action %i", policy);
 	}
@@ -1299,24 +1353,6 @@ gpm_manager_engine_perhaps_recall_cb (GpmEngine *engine, UpDevice *device, gchar
 	g_source_set_name_by_id (timer_id, "[GpmManager] perhaps-recall");
 }
 
-/**
- * gpm_manager_engine_icon_changed_cb:
- */
-static void
-gpm_manager_engine_icon_changed_cb (GpmEngine  *engine, GIcon *icon, GpmManager *manager)
-{
-	gpm_tray_icon_set_icon (manager->priv->tray_icon, icon);
-}
-
-/**
- * gpm_manager_engine_summary_changed_cb:
- */
-static void
-gpm_manager_engine_summary_changed_cb (GpmEngine *engine, gchar *summary, GpmManager *manager)
-{
-	gpm_tray_icon_set_tooltip (manager->priv->tray_icon, summary);
-}
-
 /**
  * gpm_manager_engine_low_capacity_cb:
  */
@@ -2205,6 +2241,7 @@ gpm_manager_name_lost_cb (GDBusConnection *connection,
 			  gpointer user_data)
 {
 	g_warning ("name lost %s", name);
+	exit (1);
 }
 
 /**
@@ -2282,12 +2319,6 @@ gpm_manager_init (GpmManager *manager)
 	g_signal_connect (manager->priv->control, "resume",
 			  G_CALLBACK (gpm_manager_control_resume_cb), manager);
 
-	g_debug ("creating new tray icon");
-	manager->priv->tray_icon = gpm_tray_icon_new ();
-
-	/* keep a reference for the notifications */
-	manager->priv->status_icon = gpm_tray_icon_get_status_icon (manager->priv->tray_icon);
-
 	gpm_manager_sync_policy_sleep (manager);
 
 	manager->priv->engine = gpm_engine_new ();
@@ -2295,10 +2326,6 @@ gpm_manager_init (GpmManager *manager)
 			  G_CALLBACK (gpm_manager_engine_perhaps_recall_cb), manager);
 	g_signal_connect (manager->priv->engine, "low-capacity",
 			  G_CALLBACK (gpm_manager_engine_low_capacity_cb), manager);
-	g_signal_connect (manager->priv->engine, "icon-changed",
-			  G_CALLBACK (gpm_manager_engine_icon_changed_cb), manager);
-	g_signal_connect (manager->priv->engine, "summary-changed",
-			  G_CALLBACK (gpm_manager_engine_summary_changed_cb), manager);
 	g_signal_connect (manager->priv->engine, "fully-charged",
 			  G_CALLBACK (gpm_manager_engine_fully_charged_cb), manager);
 	g_signal_connect (manager->priv->engine, "discharging",
@@ -2368,7 +2395,6 @@ gpm_manager_finalize (GObject *object)
 	g_object_unref (manager->priv->dpms);
 	g_object_unref (manager->priv->idle);
 	g_object_unref (manager->priv->engine);
-	g_object_unref (manager->priv->tray_icon);
 	g_object_unref (manager->priv->screensaver);
 	g_object_unref (manager->priv->control);
 	g_object_unref (manager->priv->button);
@@ -2376,7 +2402,6 @@ gpm_manager_finalize (GObject *object)
 	g_object_unref (manager->priv->kbd_backlight);
 	g_object_unref (manager->priv->console);
 	g_object_unref (manager->priv->client);
-	g_object_unref (manager->priv->status_icon);
 
 	g_dbus_connection_unregister_object (manager->priv->bus_connection, manager->priv->bus_object_id);
 	g_object_unref (manager->priv->bus_connection);
